<!--
SPDX-FileCopyrightText: 2022 Contributors to the rez project

SPDX-License-Identifier: Apache-2.0
-->

# Changelog

```{include} ../../CHANGELOG.md
:start-after: <!-- start-here-sphinx-start-after -->
```
